==> jc-1.4.0.tar.gz: soot/jimple/parser/node/NoCast.c <==
// public class soot.jimple.parser.node.NoCast

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 55b34935b7345d2a soot_jimple_parser_node_Cast
// @dep_class 3864d0be7cdb2bf7 soot_jimple_parser_node_NoCast

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_jimple_parser_node_Cast
// @dep_header soot_jimple_parser_node_NoCast

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/jimple/parser/node/Cast.h"
#include "soot/jimple/parser/node/NoCast.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// public static final soot.jimple.parser.node.NoCast instance
static _jc_field _jc_soot_jimple_parser_node_NoCast$field_info$instance = {
	.name=		"instance",
	.signature=	"Lsoot/jimple/parser/node/NoCast;",
	.class=		&_jc_soot_jimple_parser_node_NoCast$type,
	.type=		&_jc_soot_jimple_parser_node_NoCast$type,
	.access_flags=	_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_soot_jimple_parser_node_NoCast$fields_struct, instance),
};

// Fields
static _jc_field *const _jc_soot_jimple_parser_node_NoCast$fields[] = {
	&_jc_soot_jimple_parser_node_NoCast$field_info$instance
};

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// static void <clinit>()
//

static _jc_linenum _jc_soot_jimple_parser_node_NoCast$linenum_table$_clinit$a816641e0ba8bfef[];

static const unsigned char _jc_soot_jimple_parser_node_NoCast$param_ptypes$_clinit$a816641e0ba8bfef[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_jimple_parser_node_NoCast$method_info$_clinit$a816641e0ba8bfef = {
	.name=			"<clinit>",
	.signature=		"()V",
	.class=			&_jc_soot_jimple_parser_node_NoCast$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_parser_node_NoCast$param_ptypes$_clinit$a816641e0ba8bfef,
	.signature_hash=	_JC_JLONG(0xa816641e0ba8bfef),
	.access_flags=		_JC_ACC_STATIC,
	.function=		&_jc_soot_jimple_parser_node_NoCast$method$_clinit$a816641e0ba8bfef,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_parser_node_NoCast$linenum_table$_clinit$a816641e0ba8bfef
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_parser_node_NoCast, _clinit$a816641e0ba8bfef);

void
_jc_soot_jimple_parser_node_NoCast$method$_clinit$a816641e0ba8bfef(_jc_env *const env)
{
	struct _jc_soot_jimple_parser_node_NoCast$object *r0;

	_JC_LINE_NUMBER(7);				// 0
	r0 = _JC_NEW(env, soot_jimple_parser_node_NoCast);
	_JC_STATIC_FIELD(env, soot_jimple_parser_node_NoCast, instance, 1) = r0;
	return;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// private void <init>()
//

static _jc_linenum _jc_soot_jimple_parser_node_NoCast$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_jimple_parser_node_NoCast$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_jimple_parser_node_NoCast$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_jimple_parser_node_NoCast$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_parser_node_NoCast$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PRIVATE,
	.function=		&_jc_soot_jimple_parser_node_NoCast$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_parser_node_NoCast$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_parser_node_NoCast, _init$52f4ad9f2989aeee);

void
_jc_soot_jimple_parser_node_NoCast$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_jimple_parser_node_NoCast$object *this)
{
	struct _jc_soot_jimple_parser_node_NoCast$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(11);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object cast(java.lang.Object)
//

static _jc_linenum _jc_soot_jimple_parser_node_NoCast$linenum_table$cast$7f4f4803dccc49ec[];

static const unsigned char _jc_soot_jimple_parser_node_NoCast$param_ptypes$cast$7f4f4803dccc49ec[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_jimple_parser_node_NoCast$param_types$cast$7f4f4803dccc49ec[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_soot_jimple_parser_node_NoCast$method_info$cast$7f4f4803dccc49ec = {
	.name=			"cast",
	.signature=		"(Ljava/lang/Object;)Ljava/lang/Object;",
	.class=			&_jc_soot_jimple_parser_node_NoCast$type,
	.param_types=		&_jc_soot_jimple_parser_node_NoCast$param_types$cast$7f4f4803dccc49ec,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_soot_jimple_parser_node_NoCast$param_ptypes$cast$7f4f4803dccc49ec,
	.signature_hash=	_JC_JLONG(0x7f4f4803dccc49ec),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_parser_node_NoCast$method$cast$7f4f4803dccc49ec,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_parser_node_NoCast$vtable, soot_jimple_parser_node_NoCast.cast$7f4f4803dccc49ec) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_parser_node_NoCast$linenum_table$cast$7f4f4803dccc49ec
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_parser_node_NoCast, cast$7f4f4803dccc49ec);

_jc_java_lang_Object$object *
_jc_soot_jimple_parser_node_NoCast$method$cast$7f4f4803dccc49ec(_jc_env *const env, _jc_soot_jimple_parser_node_NoCast$object *this, _jc_java_lang_Object$object *param0)
{
	struct _jc_soot_jimple_parser_node_NoCast$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(15);				// 0
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_parser_node_NoCast$methods[] = {
	&_jc_soot_jimple_parser_node_NoCast$method_info$_clinit$a816641e0ba8bfef,
	&_jc_soot_jimple_parser_node_NoCast$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_jimple_parser_node_NoCast$method_info$cast$7f4f4803dccc49ec
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_soot_jimple_parser_node_NoCast$fields_struct _jc_soot_jimple_parser_node_NoCast$class_fields = { };

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_jimple_parser_node_NoCast$interfaces[] = {
	&_jc_soot_jimple_parser_node_Cast$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_jimple_parser_node_NoCast$imethod_hash_bucket_108[] = {
	&_jc_soot_jimple_parser_node_NoCast$method_info$cast$7f4f4803dccc49ec,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_jimple_parser_node_NoCast$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[108]=	_jc_soot_jimple_parser_node_NoCast$imethod_hash_bucket_108
};

// Interface "quick" lookup hash table
static const void *_jc_soot_jimple_parser_node_NoCast$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[108]=	&_jc_soot_jimple_parser_node_NoCast$method$cast$7f4f4803dccc49ec
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_parser_node_NoCast$instanceof_hash_bucket_42[] = {
	&_jc_soot_jimple_parser_node_Cast$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_parser_node_NoCast$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_parser_node_NoCast$instanceof_hash_bucket_119[] = {
	&_jc_soot_jimple_parser_node_NoCast$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_parser_node_NoCast$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[42]=	_jc_soot_jimple_parser_node_NoCast$instanceof_hash_bucket_42,
	[113]=	_jc_soot_jimple_parser_node_NoCast$instanceof_hash_bucket_113,
	[119]=	_jc_soot_jimple_parser_node_NoCast$instanceof_hash_bucket_119
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_parser_node_NoCast$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "soot/jimple/parser/node/Cast",	_JC_JLONG(0x55b34935b7345d2a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_parser_node_NoCast$vtype _jc_soot_jimple_parser_node_NoCast$type = {
    .type= {
	.name=			"soot/jimple/parser/node/NoCast",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_jimple_parser_node_NoCast$interfaces) / sizeof(*_jc_soot_jimple_parser_node_NoCast$interfaces),
	.interfaces=		_jc_soot_jimple_parser_node_NoCast$interfaces,
	.imethod_hash_table=	_jc_soot_jimple_parser_node_NoCast$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_jimple_parser_node_NoCast$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x3864d0be7cdb2bf7),
		.source_file=		"NoCast.java",
		.instance_size=		sizeof(_jc_soot_jimple_parser_node_NoCast$refs) + sizeof(_jc_soot_jimple_parser_node_NoCast$object),
		.num_virtual_refs=	0,
		.num_fields=		sizeof(_jc_soot_jimple_parser_node_NoCast$fields) / sizeof(*_jc_soot_jimple_parser_node_NoCast$fields),
		.fields=		_jc_soot_jimple_parser_node_NoCast$fields,
		.num_methods=		sizeof(_jc_soot_jimple_parser_node_NoCast$methods) / sizeof(*_jc_soot_jimple_parser_node_NoCast$methods),
		.methods=		_jc_soot_jimple_parser_node_NoCast$methods,
		.instanceof_hash_table=	_jc_soot_jimple_parser_node_NoCast$instanceof_hash_table,
		.class_fields=		&_jc_soot_jimple_parser_node_NoCast$class_fields,
		.num_class_depends=		sizeof(_jc_soot_jimple_parser_node_NoCast$class_depends) / sizeof(*_jc_soot_jimple_parser_node_NoCast$class_depends),
		.class_depends=		_jc_soot_jimple_parser_node_NoCast$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_jimple_parser_node_NoCast= {
	    .cast$7f4f4803dccc49ec=
		&_jc_soot_jimple_parser_node_NoCast$method$cast$7f4f4803dccc49ec,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/jimple/parser/node/NoCast.c <==
// public class soot.jimple.parser.node.NoCast

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 55b34935b7345d2a soot_jimple_parser_node_Cast
// @dep_class 3864d0be7cdb2bf7 soot_jimple_parser_node_NoCast

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header soot_jimple_parser_node_Cast
// @dep_header soot_jimple_parser_node_NoCast

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "soot/jimple/parser/node/Cast.h"
#include "soot/jimple/parser/node/NoCast.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// public static final soot.jimple.parser.node.NoCast instance
static _jc_field _jc_soot_jimple_parser_node_NoCast$field_info$instance = {
	.name=		"instance",
	.signature=	"Lsoot/jimple/parser/node/NoCast;",
	.class=		&_jc_soot_jimple_parser_node_NoCast$type,
	.type=		&_jc_soot_jimple_parser_node_NoCast$type,
	.access_flags=	_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_soot_jimple_parser_node_NoCast$fields_struct, instance),
};

// Fields
static _jc_field *const _jc_soot_jimple_parser_node_NoCast$fields[] = {
	&_jc_soot_jimple_parser_node_NoCast$field_info$instance
};

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// static void <clinit>()
//

static _jc_linenum _jc_soot_jimple_parser_node_NoCast$linenum_table$_clinit$a816641e0ba8bfef[];

static const unsigned char _jc_soot_jimple_parser_node_NoCast$param_ptypes$_clinit$a816641e0ba8bfef[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_jimple_parser_node_NoCast$method_info$_clinit$a816641e0ba8bfef = {
	.name=			"<clinit>",
	.signature=		"()V",
	.class=			&_jc_soot_jimple_parser_node_NoCast$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_parser_node_NoCast$param_ptypes$_clinit$a816641e0ba8bfef,
	.signature_hash=	_JC_JLONG(0xa816641e0ba8bfef),
	.access_flags=		_JC_ACC_STATIC,
	.function=		&_jc_soot_jimple_parser_node_NoCast$method$_clinit$a816641e0ba8bfef,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_parser_node_NoCast$linenum_table$_clinit$a816641e0ba8bfef
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_parser_node_NoCast, _clinit$a816641e0ba8bfef);

void _JC_JCNI_ATTR
_jc_soot_jimple_parser_node_NoCast$method$_clinit$a816641e0ba8bfef(_jc_env *const env)
{
	struct _jc_soot_jimple_parser_node_NoCast$object *r0;

	_JC_LINE_NUMBER(7);				// 0
	r0 = _JC_NEW(env, soot_jimple_parser_node_NoCast);
	_JC_STATIC_FIELD(env, soot_jimple_parser_node_NoCast, instance, 1) = r0;
	return;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// private void <init>()
//

static _jc_linenum _jc_soot_jimple_parser_node_NoCast$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_soot_jimple_parser_node_NoCast$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_jimple_parser_node_NoCast$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_soot_jimple_parser_node_NoCast$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_jimple_parser_node_NoCast$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PRIVATE,
	.function=		&_jc_soot_jimple_parser_node_NoCast$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_parser_node_NoCast$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_parser_node_NoCast, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_soot_jimple_parser_node_NoCast$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_soot_jimple_parser_node_NoCast$object *this)
{
	struct _jc_soot_jimple_parser_node_NoCast$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(11);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.Object cast(java.lang.Object)
//

static _jc_linenum _jc_soot_jimple_parser_node_NoCast$linenum_table$cast$7f4f4803dccc49ec[];

static const unsigned char _jc_soot_jimple_parser_node_NoCast$param_ptypes$cast$7f4f4803dccc49ec[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_soot_jimple_parser_node_NoCast$param_types$cast$7f4f4803dccc49ec[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_soot_jimple_parser_node_NoCast$method_info$cast$7f4f4803dccc49ec = {
	.name=			"cast",
	.signature=		"(Ljava/lang/Object;)Ljava/lang/Object;",
	.class=			&_jc_soot_jimple_parser_node_NoCast$type,
	.param_types=		&_jc_soot_jimple_parser_node_NoCast$param_types$cast$7f4f4803dccc49ec,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_soot_jimple_parser_node_NoCast$param_ptypes$cast$7f4f4803dccc49ec,
	.signature_hash=	_JC_JLONG(0x7f4f4803dccc49ec),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_jimple_parser_node_NoCast$method$cast$7f4f4803dccc49ec,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_jimple_parser_node_NoCast$vtable, soot_jimple_parser_node_NoCast.cast$7f4f4803dccc49ec) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_jimple_parser_node_NoCast$linenum_table$cast$7f4f4803dccc49ec
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_jimple_parser_node_NoCast, cast$7f4f4803dccc49ec);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_soot_jimple_parser_node_NoCast$method$cast$7f4f4803dccc49ec(_jc_env *const env, _jc_soot_jimple_parser_node_NoCast$object *this, _jc_java_lang_Object$object *param0)
{
	struct _jc_soot_jimple_parser_node_NoCast$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(15);				// 0
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_jimple_parser_node_NoCast$methods[] = {
	&_jc_soot_jimple_parser_node_NoCast$method_info$_clinit$a816641e0ba8bfef,
	&_jc_soot_jimple_parser_node_NoCast$method_info$_init$52f4ad9f2989aeee,
	&_jc_soot_jimple_parser_node_NoCast$method_info$cast$7f4f4803dccc49ec
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_soot_jimple_parser_node_NoCast$fields_struct _jc_soot_jimple_parser_node_NoCast$class_fields = { };

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_soot_jimple_parser_node_NoCast$interfaces[] = {
	&_jc_soot_jimple_parser_node_Cast$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_jimple_parser_node_NoCast$imethod_hash_bucket_108[] = {
	&_jc_soot_jimple_parser_node_NoCast$method_info$cast$7f4f4803dccc49ec,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_jimple_parser_node_NoCast$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[108]=	_jc_soot_jimple_parser_node_NoCast$imethod_hash_bucket_108
};

// Interface "quick" lookup hash table
static const void *_jc_soot_jimple_parser_node_NoCast$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[108]=	&_jc_soot_jimple_parser_node_NoCast$method$cast$7f4f4803dccc49ec
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_jimple_parser_node_NoCast$instanceof_hash_bucket_42[] = {
	&_jc_soot_jimple_parser_node_Cast$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_parser_node_NoCast$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_jimple_parser_node_NoCast$instanceof_hash_bucket_119[] = {
	&_jc_soot_jimple_parser_node_NoCast$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_jimple_parser_node_NoCast$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[42]=	_jc_soot_jimple_parser_node_NoCast$instanceof_hash_bucket_42,
	[101]=	_jc_soot_jimple_parser_node_NoCast$instanceof_hash_bucket_101,
	[119]=	_jc_soot_jimple_parser_node_NoCast$instanceof_hash_bucket_119
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_jimple_parser_node_NoCast$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "soot/jimple/parser/node/Cast",	_JC_JLONG(0x55b34935b7345d2a) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_jimple_parser_node_NoCast$vtype _jc_soot_jimple_parser_node_NoCast$type = {
    .type= {
	.name=			"soot/jimple/parser/node/NoCast",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_soot_jimple_parser_node_NoCast$interfaces) / sizeof(*_jc_soot_jimple_parser_node_NoCast$interfaces),
	.interfaces=		_jc_soot_jimple_parser_node_NoCast$interfaces,
	.imethod_hash_table=	_jc_soot_jimple_parser_node_NoCast$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_jimple_parser_node_NoCast$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x3864d0be7cdb2bf7),
		.source_file=		"NoCast.java",
		.instance_size=		sizeof(_jc_soot_jimple_parser_node_NoCast$refs) + sizeof(_jc_soot_jimple_parser_node_NoCast$object),
		.num_virtual_refs=	0,
		.num_fields=		sizeof(_jc_soot_jimple_parser_node_NoCast$fields) / sizeof(*_jc_soot_jimple_parser_node_NoCast$fields),
		.fields=		_jc_soot_jimple_parser_node_NoCast$fields,
		.num_methods=		sizeof(_jc_soot_jimple_parser_node_NoCast$methods) / sizeof(*_jc_soot_jimple_parser_node_NoCast$methods),
		.methods=		_jc_soot_jimple_parser_node_NoCast$methods,
		.instanceof_hash_table=	_jc_soot_jimple_parser_node_NoCast$instanceof_hash_table,
		.class_fields=		&_jc_soot_jimple_parser_node_NoCast$class_fields,
		.num_class_depends=		sizeof(_jc_soot_jimple_parser_node_NoCast$class_depends) / sizeof(*_jc_soot_jimple_parser_node_NoCast$class_depends),
		.class_depends=		_jc_soot_jimple_parser_node_NoCast$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_jimple_parser_node_NoCast= {
	    .cast$7f4f4803dccc49ec=
		&_jc_soot_jimple_parser_node_NoCast$method$cast$7f4f4803dccc49ec,
	},
    }
};
